searchData={"items":[{"type":"module","title":"Criterion","doc":"A framework to write unit tests as a list of steps. It can be used to write tests in a BDD style.","ref":"Criterion.html"},{"type":"module","title":"Usage - Criterion","doc":"- Define a feature using `feature/2` macro\n- Define scenarios under the feature using the `scenario/2` macro.\n- Inside each scenario, define steps using `step/2` block.\n- Steps can have either inline or external implementation.\n- External implementations can be reused and can be defined using `defstep/2` macro.","ref":"Criterion.html#module-usage"},{"type":"module","title":"Example - Criterion","doc":"```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n\n  feature \"Math\" do\n    setup do\n      {:ok, pi: 3.14}\n    end\n\n    scenario \"Square\" do\n      # Step with external implementation\n      step(\"Given a number greater than 5\",\n        via: &random_number/2,\n        where: [min: 2] # Options passed as second argument to the function\n      )\n\n      # Step with inline implementation\n      step \"When the number is multiplied by it self\", %{number: number} do\n        result = number * number\n        %{result: result} # will be merged to the test context\n      end\n\n      step \"Then the result is greater than the number\", %{result: result, number: number} do\n        assert result > number\n      end\n\n      # You can access data from the initial context of the test\n      step \"And pi is a constant\", %{pi: pi} do\n        assert pi == 3.14\n      end\n    end\n\n    # External step implementation\n    defstep random_number(_context, args) do\n      min = args[:min] || 0\n      %{number: min + Enum.random(0..100)}\n    end\n  end\nend\n```","ref":"Criterion.html#module-example"},{"type":"macro","title":"Criterion.defstep/2","doc":"","ref":"Criterion.html#defstep/2"},{"type":"macro","title":"Criterion.feature/2","doc":"","ref":"Criterion.html#feature/2"},{"type":"macro","title":"Criterion.scenario/2","doc":"","ref":"Criterion.html#scenario/2"},{"type":"module","title":"Criterion.Reporter","doc":"","ref":"Criterion.Reporter.html"},{"type":"function","title":"Criterion.Reporter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Criterion.Reporter.html#child_spec/1"},{"type":"module","title":"Criterion.Reporter.Store","doc":"","ref":"Criterion.Reporter.Store.html"},{"type":"function","title":"Criterion.Reporter.Store.add_step/1","doc":"","ref":"Criterion.Reporter.Store.html#add_step/1"},{"type":"function","title":"Criterion.Reporter.Store.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Criterion.Reporter.Store.html#child_spec/1"},{"type":"function","title":"Criterion.Reporter.Store.get_steps/0","doc":"","ref":"Criterion.Reporter.Store.html#get_steps/0"},{"type":"function","title":"Criterion.Reporter.Store.start/0","doc":"","ref":"Criterion.Reporter.Store.html#start/0"},{"type":"task","title":"mix criterion.gen.features","doc":"This Mix task scans the project for tests written using the `Criterion` module and generates\ncorresponding feature files in *Gherkin* syntax.","ref":"Mix.Tasks.Criterion.Gen.Features.html"},{"type":"task","title":"Usage - mix criterion.gen.features","doc":"```\nmix criterion.gen.features --dir  \n```","ref":"Mix.Tasks.Criterion.Gen.Features.html#module-usage"},{"type":"task","title":"Options - mix criterion.gen.features","doc":"- `--dir` - specify the directory to read test files from. default is `test`\n- `--file` - to generate feature files for a list of test files\n- `--output` - specify the directory to generate feature files in. default is `test/features`\n\nThe task will create the specified directory (default is `features`) and generate a `.feature` file for each test file\nin your project, converting the Criterion tests into Gherkin syntax.","ref":"Mix.Tasks.Criterion.Gen.Features.html#module-options"},{"type":"function","title":"Mix.Tasks.Criterion.Gen.Features.run/1","doc":"","ref":"Mix.Tasks.Criterion.Gen.Features.html#run/1"},{"type":"task","title":"mix criterion.gen.tests","doc":"This Mix task reads Gherkin feature files and generates corresponding test files using the Criterion module.","ref":"Mix.Tasks.Criterion.Gen.Tests.html"},{"type":"task","title":"Usage - mix criterion.gen.tests","doc":"```\nmix criterion.gen.tests\n```","ref":"Mix.Tasks.Criterion.Gen.Tests.html#module-usage"},{"type":"task","title":"Options - mix criterion.gen.tests","doc":"- `--dir` - specify the directory to read feature files from. default is `test/features`\n- `--file` - to generate test for a list of files\n- `--output` - specify the directory to generate the test files in. default is `test/features`","ref":"Mix.Tasks.Criterion.Gen.Tests.html#module-options"},{"type":"function","title":"Mix.Tasks.Criterion.Gen.Tests.run/1","doc":"","ref":"Mix.Tasks.Criterion.Gen.Tests.html#run/1"},{"type":"extras","title":"Criterion","doc":"# Criterion\n\nA library to write ExUnit tests BDD style","ref":"readme.html"},{"type":"extras","title":"Installation - Criterion","doc":"The package can be installed\nby adding `criterion` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:criterion, \"~> 0.1\", only: [:test, :dev]}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Criterion","doc":"- Define a feature using `feature/2` macro\n- Define scenarios under the feature using the `scenario/2` macro.\n- Inside each scenario, define steps using `step/2` block.\n- Steps can have either inline or external implementation.\n- External implementations can be reused and can be defined using `defstep/2` macro.","ref":"readme.html#usage"},{"type":"extras","title":"Example - Criterion","doc":"```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n\n  feature \"Math\" do\n    setup do\n      {:ok, pi: 3.14}\n    end\n\n    scenario \"Square\" do\n      # Step with external implementation\n      step(\"Given a number greater than 5\",\n        via: &random_number/2,\n        where: [min: 2] # Options passed as second argument to the function\n      )\n\n      # Step with inline implementation\n      step \"When the number is multiplied by it self\", %{number: number} do\n        result = number * number\n        %{result: result} # will be merged to the test context\n      end\n\n      step \"Then the result is greater than the number\", %{result: result, number: number} do\n        assert result > number\n      end\n\n      # You can access data from the initial context of the test\n      step \"And pi is a constant\", %{pi: pi} do\n        assert pi == 3.14\n      end\n    end\n\n    # External step implementation\n    defstep random_number(_context, args) do\n      min = args[:min] || 0\n      %{number: min + Enum.random(0..100)}\n    end\n  end\nend\n```","ref":"readme.html#example"},{"type":"extras","title":"Generating feature files - Criterion","doc":"```\nmix criterion.gen.features\n```\n\n#### Options\n\n- `--dir` - specify the directory to read test files from. default is `test`\n- `--file` - to generate feature files for a list of test files\n- `--output` - specify the directory to generate feature files in. default is `test/features`\n  `test/features/Math.feature`\n\n```feature\nFeature: Math\n\n  Scenario: Square\n    Given a number greater than 1\n    When the number is multiplied by it self\n    Then the result is greater than the number\n    And pi is a constant\n```","ref":"readme.html#generating-feature-files"},{"type":"extras","title":"Generating test files - Criterion","doc":"```\nmix criterion.gen.tests\n```\n\n#### Options\n\n- `--dir` - specify the directory to read feature files from. default is `test/features`\n- `--file` - to generate test for a list of files\n- `--output` - specify the directory to generate the test files in. default is `test/features`\n\n`test/features/math_test.exs`\n\n```elixir\ndefmodule MathTest do\n  use ExUnit.Case\n  import Criterion\n\n  feature \"Math\" do\n    scenario \"Square\" do\n      step \"Given a number greater than 1\" do\n      end\n\n      step \"When the number is multiplied by it self\" do\n      end\n\n      step \"Then the result is greater than the number\" do\n      end\n\n      step \"And pi is a constant\" do\n      end\n    end\n  end\nend\n```","ref":"readme.html#generating-test-files"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}